==> com.liferay.object.service-1.0.122-sources-commercial.jar: com/liferay/object/internal/filter/parser/InclusionOperatorsObjectFilterParser.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.filter.parser;

import com.liferay.object.constants.ObjectFilterConstants;
import com.liferay.object.model.ObjectFilter;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.vulcan.util.ObjectMapperUtil;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.osgi.service.component.annotations.Component;

/**
 * @author Feliphe Marinho
 */
@Component(
	property = {
		"filter.type=" + ObjectFilterConstants.TYPE_EXCLUDES,
		"filter.type=" + ObjectFilterConstants.TYPE_INCLUDES
	},
	service = ObjectFilterParser.class
)
public class InclusionOperatorsObjectFilterParser
	implements ObjectFilterParser {

	@Override
	public String parse(ObjectFilter objectFilter) {
		Map<String, Object> map = ObjectMapperUtil.readValue(
			Map.class, objectFilter.getJSON());

		boolean excludes = Objects.equals(
			ObjectFilterConstants.TYPE_EXCLUDES, objectFilter.getFilterType());

		if (excludes) {
			map = (Map<String, Object>)map.get("not");
		}

		List<String> values = new ArrayList<>();

		if (Objects.equals("status", objectFilter.getFilterBy())) {
			for (Object value : (Object[])map.get("in")) {
				values.add(
					StringBundler.concat(
						"(x ", excludes ? "ne " : "eq ", String.valueOf(value),
						")"));
			}

			return StringBundler.concat(
				"(", objectFilter.getFilterBy(), "/any(x:",
				StringUtil.merge(values, excludes ? " and " : " or "), "))");
		}

		for (Object value : (Object[])map.get("in")) {
			values.add(StringUtil.quote(String.valueOf(value)));
		}

		String filterString = StringBundler.concat(
			"( ", objectFilter.getFilterBy(), " in (",
			StringUtil.merge(values, StringPool.COMMA_AND_SPACE), "))");

		if (excludes) {
			return StringBundler.concat("(not ", filterString, ")");
		}

		return filterString;
	}

}

==> com.liferay.object.service-1.0.149-sources-commercial.jar: com/liferay/object/internal/filter/parser/InclusionOperatorsObjectFilterParser.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.filter.parser;

import com.liferay.object.constants.ObjectFilterConstants;
import com.liferay.object.model.ObjectFilter;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.vulcan.util.ObjectMapperUtil;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.osgi.service.component.annotations.Component;

/**
 * @author Feliphe Marinho
 */
@Component(
	property = {
		"filter.type=" + ObjectFilterConstants.TYPE_EXCLUDES,
		"filter.type=" + ObjectFilterConstants.TYPE_INCLUDES
	},
	service = ObjectFilterParser.class
)
public class InclusionOperatorsObjectFilterParser
	implements ObjectFilterParser {

	@Override
	public String parse(ObjectFilter objectFilter) {
		Map<String, Object> map = ObjectMapperUtil.readValue(
			Map.class, objectFilter.getJSON());

		boolean excludes = Objects.equals(
			ObjectFilterConstants.TYPE_EXCLUDES, objectFilter.getFilterType());

		if (excludes) {
			map = (Map<String, Object>)map.get("not");
		}

		List<String> values = new ArrayList<>();

		if (Objects.equals(objectFilter.getFilterBy(), "status")) {
			for (Object value : (Object[])map.get("in")) {
				values.add(
					StringBundler.concat(
						"(x ", excludes ? "ne " : "eq ", String.valueOf(value),
						")"));
			}

			return StringBundler.concat(
				"(", objectFilter.getFilterBy(), "/any(x:",
				StringUtil.merge(values, excludes ? " and " : " or "), "))");
		}

		for (Object value : (Object[])map.get("in")) {
			values.add(StringUtil.quote(String.valueOf(value)));
		}

		String filterString = StringBundler.concat(
			"( ", objectFilter.getFilterBy(), " in (",
			StringUtil.merge(values, StringPool.COMMA_AND_SPACE), "))");

		if (excludes) {
			return StringBundler.concat("(not ", filterString, ")");
		}

		return filterString;
	}

}
